#
# spec file for package gap-gapdoc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-gapdoc
Version:        1.6.7
Release:        1.2
Summary:        GAP: package for GAP Documentation
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://www.math.rwth-aachen.de/~Frank.Luebeck/GAPDoc/

Source:         http://www.math.rwth-aachen.de/~Frank.Luebeck/GAPDoc/GAPDoc-%version.tar.gz
BuildArch:      noarch
BuildRequires:  fdupes
BuildRequires:  gap-rpm-devel
Requires:       gap-core >= 4.11
Suggests:       gap-io >= 4.7

%description
This package contains a definition of a structure for GAP (package)
documentation, based on XML. It also contains conversion programs for
producing text, PDF or HTML versions of such documents, with
hyperlinks, if possible.

%prep
%setup -qn GAPDoc-%version

%build

%install
%gappkg_simple_install
%fdupes %buildroot/%_prefix

%files -f %name.files

%changelog
* Sat Mar 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.7
  * Better handling of very long words in text version.
  * Nicer quotation marks in HTML version.
  * Fixed a few problems with special characters in the LaTeX/PDF
    version of manuals in texts shown in typewriter font (e.g.
    ``--`` was sometimes displayed as single ``-``).
* Sun Oct  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.6
  * Now computing better labels for bibliography entries
    containing names with certain non-ASCII initials.
  * Fixed sorting of index entries containing special characters
    `<`, `>`, `&`, `\` or `_` .
  * Added a first version of `StringBibXMLEntry` for Markdown
    format.
  * Changed 'XMLValidate' and 'ValidateGAPDoc' to print a warning
    without error, when the IO package or 'xmllint' is not
    available.
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.6.2
  * Improved "InitialSubstringUTF8String" by an optional argument
    to return a string with a suffix.
  * Change access of javascript code for MathJax to https
    protocol (such that MathJax works for help pages accessed via
    https).
  * Added option ".uri := true" to 'SearchMR' to return URI
    instead of sending a request to MathSciNet.
  * Added many cases handled by 'HeuristicTranslationsLaTeX2XML',
    this is needed because MathSciNet has changed the markup for
    accented characters in many cases.
  * Made 'SearchMR' work again using 'wget' or 'curl' (MathSciNet
    is now only accessible via HTTPS).
  * Better ordering of help matches if the first word is the
    query string.
  * Escape the special characters @!|" for 'makeindex' in index
    entries for LaTeX.
  * Removed dependency on 'a4wide.sty' file in LaTeX installation.
* Sat Dec 23 2017 jengelh@inai.de
- Update to new upstream release 1.6.1
  * Slightly nicer display of header lines of ManSection's with
    long names and/or long argument lists.
  * Added an element <Constr> to be used in ManSection's on
    constructors.
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 1.6
  * Changed and documented the handling of <Alt Only="LaTeX">
    elements; its content is not reformatted.
  * Can now handle help books with empty bibliography.
  * Introduce finer distinction of <Alt>-elements for HTML
    with/without MathJax.
  * 'StringBibXMLEntry' supports now a 'rec(MathJax := true)'
    option.
  * Added a new utility function 'InitialSubstringUTF8String'.
  * 'NormalizedNameAndKey' can now find initials from UTF-8
    encoded name strings.
  * New function 'LabelsFromBibTeX'. If BibTeX is available this
    is used to unify the labels used for citations and the
    ordering of the reference list in the LaTeX, text and HTML
    version of a GAPDoc document.
  * Recognize document encoding in <?xml tag and in some other
    places case insensitively.
* Fri May 10 2013 jengelh@inai.de
- Split gapdoc (version 1.5.1) off the gap RPM package
